format_link

Function format_link 

pub fn format_link(
    style: LinkStyle,
    from: &Path,
    target: &Path,
    title: &str,
) -> String
Format a link to target (a workspace-relative canonical path) as written in the document at from, in style, with title (used only by the Markdown styles). This is what keeps an authored link native to the workspace.