serialize_value

Function serialize_value 

pub fn serialize_value(value: &Value, format: Format) -> Result<String>
Serialize any metadata value to a string in format. What serialize_mapping is for whole frontmatter blocks, this is for a value plucked out of one (the CLI’s get on a compound field).